#	url = https://github.com/rohitpid/Linux-Magic-Trackpad-2-Driver/tree/magicmouse2
#
%global	module	hid-magicmouse2
%global pname magic-mouse2

Name:		dkms-%{pname}
Version:	0.0.1
Release:	%mkrel 4
Source0:	linux-magic-trackpad2-%{version}.tar.xz
Group:		System/Kernel and hardware
License:	GPLv2
URL:		https://github.com/rohitpid/Linux-Magic-Trackpad-2-Driver/tree/magicmouse2
Summary:	Linux Apple Magic Mouse 2 and Magic Trackpad 2 Driver
Requires:   gcc >= 9.2.0

BuildRoot:	%{_tmppath}/%{name}-%{version}-buildroot
Provides:	kmod(%{module}.ko) = %{version}
Requires(post):		dkms
Requires(preun):	dkms

Obsoletes:	dkms-%{pname} < %{version}-%{release}

%description
This repository contains the linux hid-magicmouse driver with
Magic Trackpad 2 and Magic Mouse 2 support for Linux 4.18.
For older kernels you might have to diff and backport.

This driver is based off of the work of @robotrovsky, @svartalf and probably
others. The driver is tested in combination with the xf86-libinput and
xf86-mtrack driver. Please help to test this driver and report issues.

Apple Magic Trackpad 2
The driver supports bluetooth and USB for the trackpad. To connect the Trackpad
via bluetooth, it must be clicked once after it is turned on, then the Trackpad
tries to reconnect to the last paired (and trusted) connection.

Apple Magic Mouse 2
The drivers supports regular mouse motion and additionally scrolling and mouse
middle click. Middle click is a single finger click near the middle portion of
the touch surface OR a 3 finger click anywhere on the touch surface if you put
the mouse in 3 finger middle click mode (instructions on how to do this are in
the installation section. If you like this, please let me know so I can make it
the default).
Scrolling is a single finger up or down motion anywhere on the touch surface.

%prep
%setup -qn linux-magic-trackpad2-%{version}
find -type f -exec chmod 0644 {} \;

%apply_patches

%install
%__rm -rf %{buildroot}
%__install -dm755 %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}
%__cp -a ./linux/drivers/hid/* %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}
###%__rm -f %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}/{CONTRIBUTORS.md,LICENSE,README.md}
%__install -dm755 %{buildroot}%{_docdir}/%{pname}
%__install -c -m 0644 $RPM_BUILD_DIR/linux-magic-trackpad2-%{version}/README.md %{buildroot}/%{_docdir}/%{pname}/
%__install -dm755 %{buildroot}%{_sysconfdir}/X11/xorg.conf.d
%__cat <<EOF > %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/90-magictrackpad.conf
Section "InputClass"
  Identifier      "Touchpads"
  Driver          "libinput"
  MatchProduct    "Apple Inc. Magic Trackpad 2"
  MatchDevicePath "/dev/input/event*"
EndSection
EOF

%__install -dm755 %{buildroot}%{_sysconfdir}/modprobe.d
%__install -c -m 0644 $RPM_BUILD_DIR/linux-magic-trackpad2-%{version}/magicmouse2.conf %{buildroot}%{_sysconfdir}/modprobe.d/magicmouse2.conf

%__install -dm755 %{buildroot}%{_sysconfdir}/libinput
%__cat <<EOF > %{buildroot}%{_sysconfdir}/libinput/local-overrides.quirks
[Touchpad touch override]
MatchUdevType=touchpad
MatchName=*Magic Trackpad 2
AttrPressureRange=4:0
EOF

### create new dkms.conf ###
%__rm -f %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}/dkms.conf
%__cat <<EOF > %{buildroot}%{_usrsrc}/%{pname}-%{version}-%{release}/dkms.conf
PACKAGE_NAME=%{pname}
PACKAGE_VERSION=%{version}-%{release}
CLEAN="'make' clean"
MAKE="'make' SKIP_STACK_VALIDATION=1 install"
BUILT_MODULE_NAME[0]="hid-magicmouse2"
BUILT_MODULE_LOCATION[0]="./"
DEST_MODULE_LOCATION[0]="/kernel/3rdparty/magic-mouse2"
AUTOINSTALL="yes"
REMAKE_INITRD="no"
EOF

%post -n %{name}
/usr/sbin/dkms --rpm_safe_upgrade add -m %{pname} -v %{version}-%{release}
/usr/sbin/dkms --rpm_safe_upgrade build -m %{pname} -v %{version}-%{release}
/usr/sbin/dkms --rpm_safe_upgrade install -m %{pname} -v %{version}-%{release}
true
/sbin/rmmod %{module} > /dev/null 2>&1
/sbin/modprobe %{module} > /dev/null 2>&1

if [ "$1" = 1 ]; then
/sbin/modprobe %{module} > /dev/null 2>&1
echo "%{module}" >> /etc/modprobe.preload
fi

%preun -n %{name}
/usr/sbin/dkms --rpm_safe_upgrade remove -m %{pname} -v %{version}-%{release} --all
true
/sbin/rmmod %{module} > /dev/null 2>&1

if [ "$1" = 0 ]; then
/sbin/rmmod %{module} > /dev/null 2>&1
sed -i '/%{module}/ d' /etc/modprobe.preload
fi

## remove module-destdir just if it empty ##
## after dkms remove,(user's only deinstall after testing)... ##
## so prevent we not have empty folders in kernel-tree for next mklivecd ##
# in this driver we not use this,
##if [ ! -f /lib/modules/*/kernel/3rdparty/%{pname}/* ]; then
##rm -r /lib/modules/*/kernel/3rdparty/%{pname} >/dev/null 2>&1
##fi


%clean
%__rm -rf %{buildroot}

%files -n %{name}
%defattr(-,root,root)
%doc %{_docdir}/%{pname}/README.md
%{_usrsrc}/%{pname}-%{version}-%{release}/*
%config(noreplace) %{_sysconfdir}/modprobe.d/magicmouse2.conf
%config(noreplace) %{_sysconfdir}/libinput/local-overrides.quirks
%config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/90-magictrackpad.conf

%changelog
* Mon Nov 04 2019 onkelho <oh.quait at gmail.com> - 0.0.1-4pclos2019
- rename the module to hid-magicmouse2

* Thu Oct 17 2019 onkelho <oh-quait at gmail.com> - 0.0.1-3pclos2019
- rebuild --add quirks 
- 90-magictrackpad.conf to /etc/X11/xorg.conf.d/

* Thu Oct 17 2019 onkelho <oh-quait at gmail.com> - 0.0.1-2pclos2019
- rebuild -- changed moduleinstalldir to /kernel/3rdparty/magic-mouse2
- add magicmouse2.conf in sysconfdir/modprobe.d/

* Mon Oct 14 2019 onkelho <oh-quait at gmail.com> - 0.0.1-1pclos2019
- new version release


